#!/usr/bin/env python
import unittest
import copy
import json
import os
from pathlib import Path

import emodpy_tbhiv.interventions.cash as cash
import emod_api.campaign as camp


class TestCash(unittest.TestCase):
    @classmethod
    def setUpClass(self):
        import emod_tbhiv.bootstrap as dtk
        #dtk.setup('Assets')
        dtk.setup(Path("download"))
        schema_path = Path("download") / "schema.json"
        camp.set_schema(schema_path)

    def tearDown(self):
        camp.Events = []

    def test_responsive_parameters(self):
        amount = 200
        coverage = 0.8
        start_day = 5
        property_restrictions_list = [{"Age_Bin": [5, 16]}]
        nodeIDs = [4, 5, 10]
        event_name = 'Topup'
        camp.add(cash.cash(
            camp,
            amount=amount,
            coverage=coverage,
            start_day=start_day,
            property_restrictions_list=property_restrictions_list,
            nodeIDs=nodeIDs,
            event_name=event_name # not used
        ))
        camp_filename = Path("output") / "camp_cash.json"
        camp.save(Path("output") / "camp_cash.json")

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)

        event = camp_file["Events"][0]
        ec = event["Event_Coordinator_Config"]
        self.assertEqual(coverage, ec["Demographic_Coverage"])
        intervention = ec["Intervention_Config"]["Intervention_List"][0]
        self.assertEqual(amount, intervention["Budget_Amount_Constant"])
        self.assertEqual("GiveCash", intervention["class"])
        self.assertEqual("Age_Bin:[5, 16]", ec["Property_Restrictions"][0])
        self.assertEqual(event["Nodeset_Config"]["Node_List"], nodeIDs)
        self.assertEqual(event["Start_Day"], start_day)

    def test_negative_amount(self):
        amount = -1
        self.assertRaises(ValueError, cash.cash, camp, amount)

    def test_distribution(self):
        """
        Tests that setting a distribution won't allow for <0 amounts
        """
        # NYI
        pass

if __name__ == '__main__':
    unittest.main()
        





        

