#!/usr/bin/env python
import os
import unittest
import copy
import json
from intervention_test import TestIntervention
import manifest
from emodpy_tbhiv.interventions import purge_campaign_event

import emodpy_tbhiv.interventions.hsb as hsb
import emod_api.campaign as camp

from prodict import Prodict


class TestInterventionInit(unittest.TestCase):
    """
    Test all functions in the interventions/__init__.py file
    """
    def test_purge_campaign(self):
        """
        Checks that purge_campaign doesn't break with changing node property restrictions
        formats
        """
        events = [Prodict.from_dict({"Event_Coordinator_Config": {"Node_Property_Restrictions": [0], "Intervention_Config": []}}), 
        Prodict.from_dict({"Event_Coordinator_Config": {"Intervention_Config": {"Node_Property_Restrictions": [1]}}}),
        Prodict.from_dict({"Event_Coordinator_Config": {"Property_Restrictions_Within_Node": [], "Intervention_Config": []}})]

        for index, event in enumerate(events):
            purge_campaign_event(event)
            if index != 1:
                print(event)
                self.assertEqual(len(event.Event_Coordinator_Config), 1)
            else:
                print(event)
                self.assertEqual(len(event.Event_Coordinator_Config.Intervention_Config), 0)

        events_without_restrictions = [Prodict.from_dict({"Event_Coordinator_Config": {"Intervention_Config": []}}), 
        Prodict.from_dict({"Event_Coordinator_Config": {"Intervention_Config": {}}}),
        Prodict.from_dict({"Event_Coordinator_Config": {"Intervention_Config": []}})]

        for index, event in enumerate(events_without_restrictions):
            purge_campaign_event(event)
            if index != 1:
                self.assertEqual(len(event.Event_Coordinator_Config), 1)
            else:
                print(event)
                self.assertEqual(len(event.Event_Coordinator_Config.Intervention_Config), 0)



        


